@@ -38,7 +38,7 @@ el.test2 <- function(y1, y2, R = 0, ncores = 1, graph = FALSE) {
     result <- list( test = test, dof = d, pvalue = pvalue, mu = mu, runtime = runtime,
     note = paste("Chi-square approximation") )
   } else if ( R == 1 ) {
-    delta <- james(y1, y2, R = 1)$info[3]
+    delta <- Compositional::james(y1, y2, R = 1)$info[3]
     stat <- as.numeric( test / delta )
     pvalue <- as.numeric( pchisq(test / delta, d, lower.tail = FALSE) )
     result <- list(test = test, modif.test = stat, dof = d, pvalue = pvalue, mu = mu,
@@ -88,6 +88,7 @@ el.test2 <- function(y1, y2, R = 0, ncores = 1, graph = FALSE) {
     pvalue <- ( sum(tb > test) + 1 ) / (R + 1)
     result <- list(test = test, pvalue = pvalue, mu = mu, runtime = runtime,
     note = paste("Bootstrap calibration") )
+
     if ( graph ) {
       hist(tb, xlab = "Bootstrapped test statistic", main = " ")
       abline(v = test, lty = 2, lwd = 2)  ## The line is the test statistic
