@@ -9,9 +9,9 @@ scls.betest <- function(y, x, B, R = 999) {
   for ( i in 1:py )  Dmat[ ind[i, ], ind[i, ] ] <- xx
   A <- matrix(0, pyx, pyx)
   for ( i in 1:px )  A[i, ind[, i]] <- 1
-  A <- t( rbind( A, diag(pyx), -diag(pyx) ) )
+  A <- t( rbind( A, diag(pyx) ) )
   A <- A[, -c( (px + 1): pyx) ]
-  bvec <- c( rep(1, px), rep(0, pyx), rep(-1, pyx) )
+  bvec <- c( rep(1, px), rep(0, pyx) )
 
   if ( det(Dmat) < 1e-20 )  Dmat <- Matrix::nearPD(Dmat)$mat
 
